@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 from django.contrib import admin
-
-from django.contrib.auth.models import User
 from django.contrib.auth.admin import UserAdmin
+from django.contrib.auth.models import User
 
-from userprofiles import settings as up_settings
+from userprofiles.settings import up_settings
 
 
 if up_settings.USE_PROFILE and up_settings.INLINE_PROFILE_ADMIN:
@@ -18,6 +17,6 @@ if up_settings.USE_PROFILE and up_settings.INLINE_PROFILE_ADMIN:
         max_num = 1
 
     class UserProfileAdmin(UserAdmin):
-        inlines = [UserProfileInline,]
+        inlines = [UserProfileInline]
 
     admin.site.register(User, UserProfileAdmin)
